| Title: | Spatial Modeling of Infectious Diseases with Co-Variate Error |
|---|---|
| Description: | Provides tools for simulating from spatial modeling of individual level of infectious disease transmission when co-variates measured with error, and carrying out infectious disease data analyses with the same models. The epidemic models considered are distance-based model within Susceptible-Infectious-Removed (SIR) compartmental frameworks. |
| Authors: | Ruwani Herath [aut, cre], Leila Amiri [ctb], Mahmoud Torabi [ctb] |
| Maintainer: | Ruwani Herath <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.2.1 |
| Built: | 2026-06-03 10:43:09 UTC |
| Source: | https://github.com/cran/GDILM.ME |
The data which describes the areal level data (proportion of indigenous people and population) for 25 regions.
Areal_level_dataAreal_level_data
A data frame with 25 rows and 2 columns:
Region number
Population of each region
percentage of indigenous people in each region
...
Estimating parameters along with corresponding variances based on the proposed model.
Estimation( ITER, MHiteration, eps, d, nSample, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, g )Estimation( ITER, MHiteration, eps, d, nSample, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, g )
ITER |
The number of simulation runs |
MHiteration |
The number of iterations in Metropolis–Hastings algorithm |
eps |
Stopping value for MCECM algorithm |
d |
distance between cells |
nSample |
number of sample in each cell |
mm |
Number of areas. |
time |
Maximum time. |
MuxStar0 |
Mean of unobserved areal level covariates. |
MuxInd0 |
Mean of unobserved individual level covariates. |
SigmaxStar0 |
Variance of unobserved areal level covariates. |
SigmaxInd0 |
Variance of unobserved individual level covariates. |
Sigmav0 |
Variance of areal level measurement error variable. |
Sigmaw0 |
Variance of individual level measurement error variable. |
lambda0 |
Spatial dependency parameter. |
sigma0 |
Over dispersion parameter. |
delta0 |
The spatial parameter. |
alpha0 |
Initial value for intercept. |
beta10 |
Initial value for coefficient of observed individual level covariates. |
beta20 |
Initial value for coefficient of observed areal level covariates. |
beta30 |
Initial value for coefficient of unobserved individual level covariates. |
beta40 |
Initial value for coefficient of unobserved areal level covariates. |
InfPeriod |
The infectious period length. |
g |
grid dimension |
the result of the function
Estimation(1,5,0.05,2,4,4,20,0,0,1,1,0.3,0.3,0.5,0.5,2.5,0,1,1,1, 1,3,2)Estimation(1,5,0.05,2,4,4,20,0,0,1,1,0.3,0.3,0.5,0.5,2.5,0,1,1,1, 1,3,2)
Estimating parameters along with corresponding variances based on the proposed model with real data.
Estimation_RealData( ITER, MHiteration, eps, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, Di, D, Nlabel, n, cov1, cov2, ww, vv, tau )Estimation_RealData( ITER, MHiteration, eps, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, Di, D, Nlabel, n, cov1, cov2, ww, vv, tau )
ITER |
The number of simulation runs |
MHiteration |
The number of iterations in Metropolis–Hastings algorithm |
eps |
Stopping value for MCECM algorithm |
mm |
Number of areas. |
time |
Maximum time. |
MuxStar0 |
Mean vector of unobserved areal level covariates. |
MuxInd0 |
Mean vector of unobserved individual level covariates. |
SigmaxStar0 |
Variance of unobserved areal level covariates. |
SigmaxInd0 |
Variance of unobserved individual level covariates. |
Sigmav0 |
Variance of areal level measurement error variable. |
Sigmaw0 |
Variance of individual level measurement error variable. |
lambda0 |
Spatial dependency parameter. |
sigma0 |
Over dispersion parameter. |
delta0 |
The spatial parameter. |
alpha0 |
Initial value for intercept. |
beta10 |
Initial value for coefficient of observed individual level covariates. |
beta20 |
Initial value for coefficient of observed areal level covariates. |
beta30 |
Initial value for coefficient of unobserved individual level covariates. |
beta40 |
Initial value for coefficient of unobserved areal level covariates. |
InfPeriod |
The infectious period length. |
Di |
Euclidean distance between individuals |
D |
Neibourhood structure |
Nlabel |
Label for each sample from the area |
n |
Total number of individuals |
cov1 |
observed individual level covariates |
cov2 |
observed areal level covariates |
ww |
Unobserved individual level covariates |
vv |
unobserved areal level covariates |
tau |
tau |
the result of the function
Estimation_RealData(1,5,0.05,4,20,0.1,0.1,0.15,0.8,0.6,0.6,0.85, 1.1,2.7,0,1,0,1,1,3, matrix(runif(900,min = 4,max = 20),nrow=30, byrow = TRUE), matrix(c(2,-1,-1,0,-1,2,0,-1,-1,0,2,-1,0,-1,-1,2),nrow=4,byrow=TRUE), rep(1:4,c(7,6,8,9)),30,runif(30, 0, 1), runif(4,0,1),runif(30,-2,2),runif(4,0,1),sample(c(0,1),replace = TRUE, size = 30))Estimation_RealData(1,5,0.05,4,20,0.1,0.1,0.15,0.8,0.6,0.6,0.85, 1.1,2.7,0,1,0,1,1,3, matrix(runif(900,min = 4,max = 20),nrow=30, byrow = TRUE), matrix(c(2,-1,-1,0,-1,2,0,-1,-1,0,2,-1,0,-1,-1,2),nrow=4,byrow=TRUE), rep(1:4,c(7,6,8,9)),30,runif(30, 0, 1), runif(4,0,1),runif(30,-2,2),runif(4,0,1),sample(c(0,1),replace = TRUE, size = 30))
The data which describes the Individual level data (average age below 5, average age above 65 and SEFI factor) for 758 individuals.
Individual_level_dataIndividual_level_data
A data frame with 758 rows and 4 columns:
Index for individual
Average of age smaller than 5
Average of age higher 65
SEFI factor
...
Estimating parameters along with corresponding variances based on Naive model.
NaiveEstimation( ITER, MHiteration, eps, d, nSample, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, g )NaiveEstimation( ITER, MHiteration, eps, d, nSample, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, g )
ITER |
The number of simulation runs |
MHiteration |
The number of iterations in Metropolis–Hastings algorithm |
eps |
Stopping value for MCECM algorithm |
d |
distance between cells |
nSample |
number of sample in each cell |
mm |
Number of areas. |
time |
Maximum time. |
MuxStar0 |
Mean of unobserved areal level covariates. |
MuxInd0 |
Mean of unobserved individual level covariates. |
SigmaxStar0 |
Variance of unobserved areal level covariates. |
SigmaxInd0 |
Variance of unobserved individual level covariates. |
Sigmav0 |
Variance of areal level measurement error variable. |
Sigmaw0 |
Variance of individual level measurement error variable. |
lambda0 |
Spatial dependency parameter. |
sigma0 |
Over dispersion parameter. |
delta0 |
The spatial parameter. |
alpha0 |
Initial value for intercept. |
beta10 |
Initial value for coefficient of observed individual level covariates. |
beta20 |
Initial value for coefficient of observed areal level covariates. |
beta30 |
Initial value for coefficient of unobserved individual level covariates. |
beta40 |
Initial value for coefficient of unobserved areal level covariates. |
InfPeriod |
The infectious period length. |
g |
grid dimension |
The results of the function
NaiveEstimation(1,5,0.05,2,4,4,20,0,0,1,1,0.3,0.3,0.5,0.5,2.5,0,1, 1,1,1,3,2)NaiveEstimation(1,5,0.05,2,4,4,20,0,0,1,1,0.3,0.3,0.5,0.5,2.5,0,1, 1,1,1,3,2)
Estimating parameters along with corresponding variances based on Naive model with real data.
NaiveEstimation_RealData( ITER, MHiteration, eps, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, Di, D, Nlabel, n, cov1, cov2, ww, vv, tau )NaiveEstimation_RealData( ITER, MHiteration, eps, mm, time, MuxStar0, MuxInd0, SigmaxStar0, SigmaxInd0, Sigmav0, Sigmaw0, lambda0, sigma0, delta0, alpha0, beta10, beta20, beta30, beta40, InfPeriod, Di, D, Nlabel, n, cov1, cov2, ww, vv, tau )
ITER |
The number of simulation runs |
MHiteration |
The number of iterations in Metropolis–Hastings algorithm |
eps |
Stopping value for MCECM algorithm |
mm |
Number of areas. |
time |
Maximum time. |
MuxStar0 |
Mean vector of unobserved areal level covariates. |
MuxInd0 |
Mean vector of unobserved individual level covariates. |
SigmaxStar0 |
Variance of unobserved areal level covariates. |
SigmaxInd0 |
Variance of unobserved individual level covariates. |
Sigmav0 |
Variance of areal level measurement error variable. |
Sigmaw0 |
Variance of individual level measurement error variable. |
lambda0 |
Spatial dependency parameter. |
sigma0 |
Over dispersion parameter. |
delta0 |
The spatial parameter. |
alpha0 |
Initial value for intercept. |
beta10 |
Initial value for coefficient of observed individual level covariates. |
beta20 |
Initial value for coefficient of observed areal level covariates. |
beta30 |
Initial value for coefficient of unobserved individual level covariates. |
beta40 |
Initial value for coefficient of unobserved areal level covariates. |
InfPeriod |
The infectious period length. |
Di |
Euclidean distance between individuals |
D |
Neibourhood structure |
Nlabel |
Label for each sample from the area |
n |
Total number of individuals |
cov1 |
observed individual level covariates |
cov2 |
observed areal level covariates |
ww |
Unobserved individual level covariates |
vv |
unobserved areal level covariates |
tau |
tau |
The results of the function
NaiveEstimation_RealData(1,5,0.05,4,20,0.1,0.1,0.15,0.8,0.6,0.6, 0.85,1.1,2.7,0,1,0,1,1,3, matrix(runif(900,min = 4,max = 20),nrow=30, byrow = TRUE), matrix(c(2,-1,-1,0,-1,2,0,-1,-1,0,2,-1,0,-1,-1,2),nrow=4,byrow=TRUE), rep(1:4,c(7,6,8,9)),30,runif(30, 0, 1), runif(4,0,1),runif(30,-2,2),runif(4,0,1), sample(c(0,1),replace = TRUE, size = 30))NaiveEstimation_RealData(1,5,0.05,4,20,0.1,0.1,0.15,0.8,0.6,0.6, 0.85,1.1,2.7,0,1,0,1,1,3, matrix(runif(900,min = 4,max = 20),nrow=30, byrow = TRUE), matrix(c(2,-1,-1,0,-1,2,0,-1,-1,0,2,-1,0,-1,-1,2),nrow=4,byrow=TRUE), rep(1:4,c(7,6,8,9)),30,runif(30, 0, 1), runif(4,0,1),runif(30,-2,2),runif(4,0,1), sample(c(0,1),replace = TRUE, size = 30))
The data which describes the individual level data and areal data for 758 individuals.
Regional_dataRegional_data
A data frame with 758 rows and 7 columns:
Index for individual
Latitude of the area
Longitude of the area
Population of each area
SEFI factor
Number of individuals age below 5
Number of individuals age above 65
...